@@ -9,6 +9,10 @@
 
 #define VERSION "1.0.0"
 
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
+#	define _CRT_SECURE_NO_WARNINGS 1
+#endif
+
 #ifdef HAVE_CONFIG_H
 #	include <config.h>
 #endif
@@ -16,7 +20,7 @@
 #include <ncftp.h>				/* Library header. */
 #include <Strn.h>				/* Library header. */
 
-#if defined(WIN32) || defined(_WINDOWS)
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 #	include "..\ncftpget\gpshare.h"
 #else
 #	include "../ncftpget/gpshare.h"
@@ -40,7 +44,7 @@ char gDebugCurCatalogFile[256];
 char gConfigFileNameOnly[80];	/* filename only */
 char gUmaskStr[16];
 int gDeleteRemoteFiles = 1;
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 int gRPathsToLowercase = 0;
 #endif
 FTPFileInfoList gFiles, gFilesToDelete, gPrevCatalog, gCurCatalog;
@@ -72,10 +76,10 @@ PruneUnwantedFilesFromFileList(FTPFileInfoListPtr filp)
 			nextfip = RemoveFileInfo(filp, fip);
 		else if (strcasecmp(fip->lname, gCatalogFileNameOnly) == 0)
 			nextfip = RemoveFileInfo(filp, fip);
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		else if (gRPathsToLowercase != 0) {
-			strlwr(fip->lname);
-			strlwr(fip->relname);
+			_strlwr(fip->lname);
+			_strlwr(fip->relname);
 		}
 #endif
 	}
@@ -152,9 +156,9 @@ BreadthFirstCaseCmp(const void *a, const void *b)
 	else if (deptha > depthb)
 		return (1);
 
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	/* Paths are generally not case-sensitive. */
-	return (stricmp(cpa, cpb));
+	return (_stricmp(cpa, cpb));
 #elif defined(HAVE_SETLOCALE)
 	return (strcoll(cpa, cpb));
 #else
@@ -174,11 +178,12 @@ LoadCatalogFromFile(const char *const catalogFileName, FTPFileInfoListPtr const
 	char *tokstart;
 	FTPFileInfo fi;
 	int havesz, havemt;
+	unsigned int mt;
 
 	InitFileInfoList(filp);
 	fp = fopen(
 		catalogFileName,
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		"rt"
 #else
 		"r"
@@ -228,7 +233,8 @@ LoadCatalogFromFile(const char *const catalogFileName, FTPFileInfoListPtr const
 			havesz++;
 		} else if (strncasecmp(tokstart, "Date: ",  6) == 0) {
 			cp = tokstart + 6;
-			(void) sscanf(cp, "%u", (unsigned int *) &fi.mdtm);
+			(void) sscanf(cp, "%u", (unsigned int *) &mt);
+			fi.mdtm = (time_t) mt;
 			havemt++;
 		}
 
@@ -453,7 +459,7 @@ Other config file options:\n\
   port                     (default: 21)\n\
   umask                    (default depends on server)\n\
   textexts                 (default: %s)\n", gTextExts);
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	(void) fprintf(fp, "\n\
   pathnames-to-lowercase   (default: no)\n");
 #endif
@@ -506,7 +512,7 @@ UpdateCatalogFile(void)
 
 	fp = fopen(
 		gCatalogFile,
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		"wt"
 #else
 		"w"
@@ -788,7 +794,7 @@ SetDebugLog(const char *const fn)
 	else
 		gConn.debugLog = fopen(
 			fn,
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 			"wt"
 #else
 			"w"
@@ -805,7 +811,8 @@ ReadSyncputConfigFile(const char *fn, FTPCIPtr cip)
 	char line[128];
 	char *cp, *tokstart;
 
-#ifndef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
+#else
 	(void) chmod(fn, 0600);
 #endif
 
@@ -813,7 +820,7 @@ ReadSyncputConfigFile(const char *fn, FTPCIPtr cip)
 	STRNCPY(gConfigFileNameOnly, cp ? (cp + 1) : fn);
 
 	fp = fopen(fn,
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		"rt"
 #else
 		"r"
@@ -872,7 +879,7 @@ ReadSyncputConfigFile(const char *fn, FTPCIPtr cip)
 			(void) STRNCPY(gUmaskStr, tokstart + 6);
 		} else if (strncmp(tokstart, "sync-deletes", 12) == 0) {
 			gDeleteRemoteFiles = StrToBool(tokstart + 13);
-#ifdef WIN32
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 		} else if (strncmp(tokstart, "pathnames-to-lowercase", 22) == 0) {
 			gRPathsToLowercase = StrToBool(tokstart + 23);
 #endif
